@@ -38,6 +38,8 @@ class EnvironmentModel:
     project: ProjectModel
     feature_states: typing.List[FeatureStateModel] = field(default_factory=list)
     allow_client_traits: bool = True
+    updated_at: datetime = field(default_factory=utcnow_with_tz)
+    use_mv_v2_evaluation: bool = False
 
     amplitude_config: IntegrationModel = None
     segment_config: IntegrationModel = None
@@ -45,6 +47,7 @@ class EnvironmentModel:
     heap_config: IntegrationModel = None
     dynatrace_config: IntegrationModel = None
     webhook_config: WebhookModel = None
+    hide_disabled_flags: bool = None
 
     _INTEGRATION_ATTS = [
         "amplitude_config",
@@ -79,3 +82,8 @@ class EnvironmentModel:
                     "entity_selector": integration_config.entity_selector,
                 }
         return integrations_data
+
+    def get_hide_disabled_flags(self) -> bool:
+        if self.hide_disabled_flags is not None:
+            return self.hide_disabled_flags
+        return self.project.hide_disabled_flags
